from ape import plugins
from ape.api import create_network_type

from .ecosystem import NETWORKS, Ethereum


@plugins.register(plugins.EcosystemPlugin)
def ecosystems():
    yield Ethereum


@plugins.register(plugins.NetworkPlugin)
def networks():
    for network_name, network_params in NETWORKS.items():
        yield "ethereum", network_name, create_network_type(*network_params)

    # TODO: Move to ape-test 1st party plugin
    yield "ethereum", "development", create_network_type(chain_id=69, network_id=69)



from ape import plugins

from .explorer import Etherscan

NETWORKS = [
    "mainnet",
    "ropsten",
    "rinkeby",
    "kovan",
    "goerli",
]


@plugins.register(plugins.ExplorerPlugin)
def explorers():
    for network_name in NETWORKS:
        yield "ethereum", network_name, Etherscan



from ape import plugins
from ape.api import create_network_type

from .providers import LocalNetwork


@plugins.register(plugins.NetworkPlugin)
def networks():
    yield "ethereum", "development", create_network_type(chain_id=69, network_id=69)


@plugins.register(plugins.ProviderPlugin)
def providers():
    yield "ethereum", "development", LocalNetwork



from ape.api import ExplorerAPI

ETHERSCAN_URI = (
    lambda n: (f"https://{n}.etherscan.io/" if n != "mainnet" else "https://etherscan.io/")
    + "{0}/{1}/"
)


class Etherscan(ExplorerAPI):
    def get_address_url(self, address: str) -> str:
        return ETHERSCAN_URI(self.network.name).format("address", address)

    def get_transaction_url(self, transaction_hash: str) -> str:
        return ETHERSCAN_URI(self.network.name).format("tx", transaction_hash)
